<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

/*
|--------------------------------------------------------------------------
| Frontend
|--------------------------------------------------------------------------|
*/

// Home
Route::name('home')->get('/', 'Front\PostController@index');

// Contact
Route::resource('contacts', 'Front\ContactController', ['only' => ['create', 'store']]);

// Posts and comments
Route::prefix('posts')->namespace('Front')->group(function () {
    Route::name('posts.display')->get('{slug}', 'PostController@show');
    Route::name('posts.tag')->get('tag/{tag}', 'PostController@tag');
    Route::name('posts.search')->get('', 'PostController@search');
    Route::name('posts.comments.store')->post('{post}/comments', 'CommentController@store');
    Route::name('posts.comments.comments.store')->post('{post}/comments/{comment}/comments', 'CommentController@store');
    Route::name('posts.comments')->get('{post}/comments/{page}', 'CommentController@comments');
});

Route::resource('comments', 'Front\CommentController', [
    'only' => ['update', 'destroy'],
    'names' => ['destroy' => 'front.comments.destroy']
]);

Route::name('category')->get('category/{category}', 'Front\PostController@category');

// Authentification
Auth::routes();


/*
|--------------------------------------------------------------------------
| Backend
|--------------------------------------------------------------------------|
*/

Route::prefix('admin')->namespace('Back')->group(function () {

    Route::middleware('redac')->group(function () {

        //Route::name('admin')->get('/', 'AdminController@index');

        // Posts
        Route::name('posts.seen')->put('posts/seen/{post}', 'PostController@updateSeen')->middleware('can:manage,post');
        Route::name('posts.active')->put('posts/active/{post}/{status?}', 'PostController@updateActive')->middleware('can:manage,post');
        Route::resource('posts', 'PostController');

        // Notifications
        Route::name('notifications.index')->get('notifications/{user}', 'NotificationController@index');
        Route::name('notifications.update')->put('notifications/{notification}', 'NotificationController@update');

        // Medias
        Route::view('medias', 'back.medias')->name('medias.index');

    });

    Route::middleware('admin')->group(function () {

        // Users
        Route::name('users.seen')->put('users/seen/{user}', 'UserController@updateSeen');
        Route::name('users.valid')->put('users/valid/{user}', 'UserController@updateValid');
        Route::resource('users', 'UserController', ['only' => [
            'index', 'edit', 'update', 'destroy'
        ]]);

        // Categories
        Route::resource('categories', 'CategoryController', ['except' => 'show']);

        // Contacts
        Route::name('contacts.seen')->put('contacts/seen/{contact}', 'ContactController@updateSeen');
        Route::resource('contacts', 'ContactController', ['only' => [
            'index', 'destroy'
        ]]);

        // Comments
        Route::name('comments.seen')->put('comments/seen/{comment}', 'CommentController@updateSeen');
        Route::resource('comments', 'CommentController', ['only' => [
            'index', 'destroy'
        ]]);

        // Settings
        Route::name('settings.edit')->get('settings', 'AdminController@settingsEdit');
        Route::name('settings.update')->put('settings', 'AdminController@settingsUpdate');

    });

});



/*
Route::group(['middleware' => ['api','cors']], function () {
    Route::post('auth/register', 'Auth\RegisterController@create');
    Route::post('auth/login', 'Auth\ApiAuthController@login');
});*/


/********************************************** NotificationController *********************************************************************************/
Route::get('/notification/v1/getAllNotificationWithToken/{token}', ['uses' => 'NotificationController@getAllNotificationWithToken']);     //permet de renvoyer toutes les notifications d'un user avec token

Route::get('/notification/v1/getAllNotificationWithUserId/{user_id}', ['uses' => 'NotificationController@getAllNotificationWithUserId']);   //permet de renvoyer toutes les notifications d'un user avec user_id

Route::post('/notification/v1/updatedFieldLu', ['uses' => 'NotificationController@updatedFieldLu']);    //permet de mettre à jour le champ Lu à 1

Route::post('/notification/v1/delete', ['uses' => 'NotificationController@deleteNotification']);        //permet de supprimer une ou plusieurs notifications



/********************************************** ExcelController *********************************************************************************/
Route::get('/excel/view', ['uses' => 'ExcelController@index']);           //permet de renvoyer la view importExport.blade

Route::get('/excel/export/excel/{type}/{tontine_id}/{cycle_id}', ['uses' => 'ExcelController@downloadExcel']);       //permet de download le fichier excel selon le type (xls, xlsx ou csv)

Route::get('/excel/pdfview',array('as'=>'pdfview','uses'=>'ExcelControllerController@pdfview'));

//Route::get('/bid/export/excel', ['uses' => 'ExcelController@downloadExcelTest']);







/** ******************              mookatika   08/05/2018 christopher          ***********************************************************/

/** ******************                      ExterieurController                 ***********************************************************/

// Route::get('/', ['uses' => 'ExterieurController@login']);

// Route::get('/register', ['uses' => 'ExterieurController@register']);

//Route::get('/logout', 'Auth\LoginController@logout');

Route::get('/','ContributionController@accueil');

Route::get('/{message}','ContributionController@accueil1');

Route::post('/user/login/web','ContributionController@login');          //permet d'afficher la page principale d'administration pour se login

Route::get('/dashboard','ContributionController@index1');           //permet d'afficher la page principale après le login (dashboard)

Route::get('/home/{pseudo}','ContributionController@index');           //permet d'afficher la page principale après le login (dashboard)         

Route::get('/logout', 'ContributionController@logout');                //permet de se déconnecter

Route::get('/user/get/AllUsers', 'ContributionController@getUsers');       //permet d'afficher la liste des users

Route::get('user/update/{user_id}', 'ContributionController@viewUpdateUser');      //permet de renvoyer la vue pour éditer les infos sur un user

Route::post('user/update_statut', 'ContributionController@updateStatut');          //permet d'update le statut du user

Route::get('user/add', 'ContributionController@addUser');             //permet de renvoyer le formulaire pour add un user

Route::post('user/save', 'ContributionController@saveUser');           //permet de save le user






Route::post('/user/account/v1/createaccount', ['uses' => 'ExterieurController@signUp']);    //pour créer le compte du user

Route::post('/user/account/v1/auth',['uses' => 'ExterieurController@signIn']);          // pour logger le user

Route::get('/user/account/v1/profile/{token}',['uses' => 'ExterieurController@getUserProfil']);         // permet de donner le profil d'un user

Route::get('/user/account/v2/profile/{user_id}',['uses' => 'ExterieurController@getUserProfilwithId']);         // permet de donner le profil d'un user avec user_id

Route::put('/user/account/v1/profile/{token}',['uses' => 'ExterieurController@EditProfileUser']);           // permet d'update les infos d'un user

Route::post('/user/account/v1/code/password',['uses' => 'ExterieurController@SendCodeToChangePassword']);  //permet d'envoyer le code au user par mail qui va lui permettre de changer son password

Route::post('/user/account/v1/confirmcode/password',['uses' => 'ExterieurController@confirmCode']);    //permet de confirmer le code entré par le user

Route::post('/user/account/v1/changepassword',['uses' => 'ExterieurController@changePassword']);   //permet de changer le password du user

Route::post('/user/account/v1/changepasswordWeb',['uses' => 'ExterieurController@changePasswordWeb']);   //permet de changer le password du user sur le Web

Route::post('/user/feedback/v1/save', ['uses' => 'ExterieurController@saveFeedBack']);    //permet d'enregistrer un feedback fait par un user

Route::get('/user/feedback/v1/getAll', ['uses' => 'ExterieurController@getAllFeedBack']);    //permet de renvoyer tous les feedback









/** ******************              GIZ     15/05/2019 christopher          ***********************************************************/


/** ******************                      StatutController                    ***********************************************************/

Route::get('/statut/get', ['uses' => 'StatutController@getStatut']);    //permet de renvoyer tous les statuts

Route::post('/statut/post', ['uses' => 'StatutController@postStatut']);    //permet de save un statut

Route::post('/statut/edit/{statut_id}', ['uses' => 'StatutController@editStatut']);    //permet d'éditer un statut

Route::get('/statut/delete/{statut_id}', ['uses' => 'StatutController@deleteStatut']);    //permet de supprimer un statut




/** ******************                      DisponibiliteController                 ***********************************************************/

Route::get('/disponibilite/get', ['uses' => 'DisponibiliteController@getDisponibilite']);    //permet de renvoyer toutes les disponibilités

Route::post('/disponibilite/post', ['uses' => 'DisponibiliteController@postDisponibilite']);    //permet de save une disponibilité

Route::post('/disponibilite/edit/{disponibilite_id}', ['uses' => 'DisponibiliteController@editDisponibilite']);    //permet d'éditer une disponibilité

Route::get('/disponibilite/delete/{disponibilite_id}', ['uses' => 'DisponibiliteController@deleteDisponibilite']);    //permet de supprimer une disponibilité





/** ******************                      RecommandationController                    ***********************************************************/

Route::get('/recommandation/get', ['uses' => 'RecommandationController@getRecommandation']);    //permet de renvoyer toutes les recommandations

Route::post('/recommandation/post', ['uses' => 'RecommandationController@postRecommandation']);    //permet de save une recommandation

Route::post('/recommandation/edit/{recommandation_id}', ['uses' => 'RecommandationController@editRecommandation']);    //permet d'éditer une recommandation

Route::get('/recommandation/delete/{recommandation_id}', ['uses' => 'RecommandationController@deleteRecommandation']);    //permet de supprimer une recommandation





/** ******************                      NiveauFormationController                   ***********************************************************/

Route::get('/niveau_formation/get', ['uses' => 'NiveauFormationController@getNiveauFormation']);    //permet de renvoyer tous les niveaux de formation

Route::post('/niveau_formation/post', ['uses' => 'NiveauFormationController@postNiveauFormation']);    //permet de save un niveau de formation

Route::post('/niveau_formation/edit/{niveau_formation_id}', ['uses' => 'NiveauFormationController@editNiveauFormation']);    //permet d'éditer un niveau de formation

Route::get('/niveau_formation/delete/{niveau_formation_id}', ['uses' => 'NiveauFormationController@deleteNiveauFormation']);    //permet de supprimer un niveau de formation





/** ******************                      ProfilController                    ***********************************************************/

Route::get('/profil/get', ['uses' => 'ProfilController@getProfil']);    //permet de renvoyer tous les profils

Route::post('/profil/post', ['uses' => 'ProfilController@postProfil']);    //permet de save un profil

Route::post('/profil/edit/{profil_id}', ['uses' => 'ProfilController@editProfil']);    //permet d'éditer un profil

Route::get('/profil/delete/{profil_id}', ['uses' => 'ProfilController@deleteProfil']);    //permet de supprimer un profil





/** ******************                      ExperienceGeographiqueController                    ***********************************************************/

Route::get('/experience_geographique/get', ['uses' => 'ExperienceGeographiqueController@getExperienceGeographique']);    //permet de renvoyer toutes les expériences géographiques

Route::post('/experience_geographique/post', ['uses' => 'ExperienceGeographiqueController@postExperienceGeographique']);    //permet de save une expérience géographique

Route::post('/experience_geographique/edit/{experience_geographique_id}', ['uses' => 'ExperienceGeographiqueController@editExperienceGeographique']);    //permet d'éditer une expérience géographique

Route::get('/experience_geographique/delete/{experience_geographique_id}', ['uses' => 'ExperienceGeographiqueController@deleteExperienceGeographique']);    //permet de supprimer une expérience géographique




/** ******************                      DomainesController                  ***********************************************************/

Route::get('/domaines/get', ['uses' => 'DomainesController@getDomaines']);    //permet de renvoyer tous les domaines

Route::post('/domaines/post', ['uses' => 'DomainesController@postDomaines']);    //permet de save un domaine

Route::post('/domaines/edit/{domaines_id}', ['uses' => 'DomainesController@editDomaines']);    //permet d'éditer un domaine

Route::get('/domaines/delete/{domaines_id}', ['uses' => 'DomainesController@deleteDomaines']);    //permet de supprimer un domaine




/** ******************                      FormeJuridiqueController                    ***********************************************************/

Route::get('/forme_juridique/get', ['uses' => 'FormeJuridiqueController@getFormeJuridique']);    //permet de renvoyer toutes les formes juridiques

Route::post('/forme_juridique/post', ['uses' => 'FormeJuridiqueController@postFormeJuridique']);    //permet de save une forme juridique

Route::post('/forme_juridique/edit/{forme_juridique_id}', ['uses' => 'FormeJuridiqueController@editFormeJuridique']);    //permet d'éditer une forme juridique

Route::get('/forme_juridique/delete/{forme_juridique_id}', ['uses' => 'FormeJuridiqueController@deleteFormeJuridique']);    //permet de supprimer une forme juridique






/** ******************                      ConsultantController                    ***********************************************************/

Route::post('/consultant/post/{token}', ['uses' => 'ConsultantController@postConsultant']);    //permet de save un consultant

Route::post('/consultant/update/{consultant_id}/{token}', ['uses' => 'ConsultantController@updateConsultant']);    //permet d'update les infos d'un consultant

Route::get('/consultant/delete/{consultant_id}/{token}', ['uses' => 'ConsultantController@deleteConsultant']);    //permet de supprimer les infos d'un consultant

Route::get('/consultant/get/byPage/{num_page}/{nbre_donnees_par_page}', ['uses' => 'ConsultantController@getConsultantByPage']);      //permet de renvoyer la liste des consultants sans filtre à partir d'un numéro de page.

Route::get('/consultant/get/infos/sidebar', ['uses' => 'ConsultantController@getInfoSidebar']);     //permet de get les domaines d'intervention, les profils et les niveaux de formation en comptant les consultants dans chaque domaine, dans chaque profil et dans chaque niveau de formation

Route::post('/consultant/export/file', ['uses' => 'ConsultantController@exportZipFile']);   //permet d'exporter dans un dossier zip tous les cv des consultants d'une page

Route::get('/consultant/get/statistique', ['uses' => 'ConsultantController@getStatistique']);   //permet de renvoyer les statistiques des consultants en genre sur les CVs et par domaine d'intervention

Route::get('/consultant/get/all', ['uses' => 'ConsultantController@getConsultant']);      //permet de renvoyer la liste des consultants sans filtre à partir d'un numéro de page.





/** ******************                      CabinetBureauEtudeController                    ***********************************************************/

Route::post('/cabinet/bureau/etude/post/{token}', ['uses' => 'CabinetBureauEtudeController@postCabinetBureauEtude']);    //permet de save un cabinet ou bureau d'étude

Route::post('/cabinet/bureau/etude/update/{cabinet_id}/{token}', ['uses' => 'CabinetBureauEtudeController@updateCabinetBureauEtude']);    //permet d'update les infos d'un cabinet ou bureau d'étude

Route::get('/cabinet/bureau/etude/delete/{cabinet_id}/{token}', ['uses' => 'CabinetBureauEtudeController@deleteCabinetBureauEtude']);    //permet de supprimer les infos d'un cabinet ou bureau d'étude


Route::get('/cabinet/bureau/etude/get/byPage/{num_page}/{nbre_donnees_par_page}', ['uses' => 'CabinetBureauEtudeController@getCabinetBureauEtudeByPage']);      //permet de renvoyer la liste des cabinets et bureaux d'étude sans filtre à partir d'un numéro de page.

Route::get('/cabinet/bureau/etude/get/infos/sidebar', ['uses' => 'CabinetBureauEtudeController@getInfoSidebar']);     //permet de get les domaines d'intervention et les profils en comptant les cabinets ou bureaux d'étude dans chaque domaine et dans chaque profil

Route::post('/cabinet/bureau/etude/export/file', ['uses' => 'CabinetBureauEtudeController@exportZipFile']);   //permet d'exporter dans un dossier zip tous les fichiers des cabinets ou bureaux d'étude d'une page

Route::get('/cabinet/bureau/etude/get/statistique', ['uses' => 'CabinetBureauEtudeController@getStatistique']);   //permet de renvoyer les statistiques des cabinets d'étude par domaine d'intervention

Route::get('/cabinet/bureau/etude/get/all', ['uses' => 'CabinetBureauEtudeController@getCabinetBureauEtude']);      //permet de renvoyer la liste des cabinets et bureaux d'étude sans filtre à partir d'un numéro de page.




Route::get('/consultant/create','DataController@create');

Route::get('/consultant/pdftotext', 'ConsultantController@pdfToText');



/** ******************                      ONGAssociationController                    ***********************************************************/

Route::post('/ong/association/post/{token}', ['uses' => 'ONGAssociationController@postONGAssociation']);    //permet de save une ONG ou Association

Route::post('/ong/association/update/{ong_association_id}/{token}', ['uses' => 'ONGAssociationController@updateONGAssociation']);    //permet d'update les infos d'une ONG ou Association

Route::get('/ong/association/delete/{ong_association_id}/{token}', ['uses' => 'ONGAssociationController@deleteONGAssociation']);    //permet de supprimer les infos d'une ONG ou Association


Route::get('/ong/association/get/byPage/{num_page}/{nbre_donnees_par_page}', ['uses' => 'ONGAssociationController@getONGAssociationByPage']);      //permet de renvoyer la liste des cabinets et bureaux d'étude sans filtre à partir d'un numéro de page.

Route::get('/ong/association/get/infos/sidebar', ['uses' => 'ONGAssociationController@getInfoSidebar']);     //permet de get les domaines d'intervention et les profils en comptant les ONG Associations dans chaque domaine et dans chaque profil

Route::post('/ong/association/export/file', ['uses' => 'ONGAssociationController@exportZipFile']);   //permet d'exporter dans un dossier zip tous les fichiers des ONG ou Association d'une page

Route::get('/ong/association/get/statistique', ['uses' => 'ONGAssociationController@getStatistique']);   //permet de renvoyer les statistiques des ONG ou Association par domaine d'intervention

Route::get('/ong/association/get/all', ['uses' => 'ONGAssociationController@getONGAssociation']);      //permet de renvoyer la liste des ONG ou associations sans filtre à partir d'un numéro de page.


/** ******************                     ExterieurController                    ***********************************************************/
Route::get('/users/get/role', ['uses' => 'ExterieurController@getRole']);   //permet de get tous les rôles

Route::post('/users/signUp', ['uses' => 'ExterieurController@signUp']);   //permet de signUp un user qui peut avoir accès au système. N.B: Ce sont juste les admins qui peuvent enregistrer ces users

Route::post('/users/signIn', ['uses' => 'ExterieurController@signIn']);   //permet de signIn un user qui peut avoir accès au système. N.B: Ce sont juste les admins qui peuvent enregistrer ces users

Route::get('/users/get', ['uses' => 'ExterieurController@getUser']);    //permet de get les users

Route::post('/users/update/{token}', ['uses' => 'ExterieurController@updateUser']);    //permet d'update les infos d'un user

Route::get('/users/delete/{user_id}', ['uses' => 'ExterieurController@deleteUser']);    //permet de supprimer ou de désactiver un user

Route::get('/users/active/{user_id}', ['uses' => 'ExterieurController@activeUser']);    //permet d'activer un user

Route::post('/users/update/role/{user_id}', ['uses' => 'ExterieurController@updateRoleUser']);    //permet de changer le rôle un user





 
/*
TRUNCATE TABLE cabinet_bureau_etude;
TRUNCATE TABLE consultant;
TRUNCATE TABLE contact_users;
TRUNCATE TABLE courriel_users;
TRUNCATE TABLE cv_users;
TRUNCATE TABLE domaine_expertise_users;
TRUNCATE TABLE experience_geographique_users;
TRUNCATE TABLE file_cabinet_bureau_etude;
TRUNCATE TABLE profil_users;
*/




